==> zio-aws-location_2.12-6.20.97.2-sources.jar: zio/aws/location/model/ApiKeyRestrictions.scala <==
package zio.aws.location.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.location.model.primitives.{GeoArn, RefererPattern, ApiKeyAction}
import scala.jdk.CollectionConverters._
final case class ApiKeyRestrictions(
    allowActions: Iterable[ApiKeyAction],
    allowReferers: Optional[Iterable[RefererPattern]] = Optional.Absent,
    allowResources: Iterable[GeoArn]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.location.model.ApiKeyRestrictions = {
    import ApiKeyRestrictions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.location.model.ApiKeyRestrictions
      .builder()
      .allowActions(allowActions.map { item =>
        ApiKeyAction.unwrap(item): java.lang.String
      }.asJavaCollection)
      .optionallyWith(
        allowReferers.map(value =>
          value.map { item =>
            RefererPattern.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.allowReferers)
      .allowResources(allowResources.map { item =>
        GeoArn.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.location.model.ApiKeyRestrictions.ReadOnly =
    zio.aws.location.model.ApiKeyRestrictions.wrap(buildAwsValue())
}
object ApiKeyRestrictions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.location.model.ApiKeyRestrictions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.location.model.ApiKeyRestrictions =
      zio.aws.location.model.ApiKeyRestrictions(
        allowActions,
        allowReferers.map(value => value),
        allowResources
      )
    def allowActions: List[ApiKeyAction]
    def allowReferers: Optional[List[RefererPattern]]
    def allowResources: List[GeoArn]
    def getAllowActions: ZIO[Any, Nothing, List[ApiKeyAction]] =
      ZIO.succeed(allowActions)
    def getAllowReferers: ZIO[Any, AwsError, List[RefererPattern]] =
      AwsError.unwrapOptionField("allowReferers", allowReferers)
    def getAllowResources: ZIO[Any, Nothing, List[GeoArn]] =
      ZIO.succeed(allowResources)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.location.model.ApiKeyRestrictions
  ) extends zio.aws.location.model.ApiKeyRestrictions.ReadOnly {
    override val allowActions: List[ApiKeyAction] = impl
      .allowActions()
      .asScala
      .map { item =>
        zio.aws.location.model.primitives.ApiKeyAction(item)
      }
      .toList
    override val allowReferers: Optional[List[RefererPattern]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.allowReferers())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.location.model.primitives.RefererPattern(item)
          }.toList
        )
    override val allowResources: List[GeoArn] = impl
      .allowResources()
      .asScala
      .map { item =>
        zio.aws.location.model.primitives.GeoArn(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.location.model.ApiKeyRestrictions
  ): zio.aws.location.model.ApiKeyRestrictions.ReadOnly = new Wrapper(impl)
}

==> zio-aws-location_2.12-7.28.29.2-sources.jar: zio/aws/location/model/ApiKeyRestrictions.scala <==
package zio.aws.location.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.location.model.primitives.{
  RefererPattern,
  GeoArnV2,
  ApiKeyAction
}
import scala.jdk.CollectionConverters._
final case class ApiKeyRestrictions(
    allowActions: Iterable[ApiKeyAction],
    allowResources: Iterable[GeoArnV2],
    allowReferers: Optional[Iterable[RefererPattern]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.location.model.ApiKeyRestrictions = {
    import ApiKeyRestrictions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.location.model.ApiKeyRestrictions
      .builder()
      .allowActions(allowActions.map { item =>
        ApiKeyAction.unwrap(item): java.lang.String
      }.asJavaCollection)
      .allowResources(allowResources.map { item =>
        GeoArnV2.unwrap(item): java.lang.String
      }.asJavaCollection)
      .optionallyWith(
        allowReferers.map(value =>
          value.map { item =>
            RefererPattern.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.allowReferers)
      .build()
  }
  def asReadOnly: zio.aws.location.model.ApiKeyRestrictions.ReadOnly =
    zio.aws.location.model.ApiKeyRestrictions.wrap(buildAwsValue())
}
object ApiKeyRestrictions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.location.model.ApiKeyRestrictions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.location.model.ApiKeyRestrictions =
      zio.aws.location.model.ApiKeyRestrictions(
        allowActions,
        allowResources,
        allowReferers.map(value => value)
      )
    def allowActions: List[ApiKeyAction]
    def allowResources: List[GeoArnV2]
    def allowReferers: Optional[List[RefererPattern]]
    def getAllowActions: ZIO[Any, Nothing, List[ApiKeyAction]] =
      ZIO.succeed(allowActions)
    def getAllowResources: ZIO[Any, Nothing, List[GeoArnV2]] =
      ZIO.succeed(allowResources)
    def getAllowReferers: ZIO[Any, AwsError, List[RefererPattern]] =
      AwsError.unwrapOptionField("allowReferers", allowReferers)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.location.model.ApiKeyRestrictions
  ) extends zio.aws.location.model.ApiKeyRestrictions.ReadOnly {
    override val allowActions: List[ApiKeyAction] = impl
      .allowActions()
      .asScala
      .map { item =>
        zio.aws.location.model.primitives.ApiKeyAction(item)
      }
      .toList
    override val allowResources: List[GeoArnV2] = impl
      .allowResources()
      .asScala
      .map { item =>
        zio.aws.location.model.primitives.GeoArnV2(item)
      }
      .toList
    override val allowReferers: Optional[List[RefererPattern]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.allowReferers())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.location.model.primitives.RefererPattern(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.location.model.ApiKeyRestrictions
  ): zio.aws.location.model.ApiKeyRestrictions.ReadOnly = new Wrapper(impl)
}
